@@ -47,8 +47,6 @@
 
 #define XFIXES_CURSOR_HIDING_MAJOR 4
 
-#define IDLE_TIME 1
-
 #define GSD_CURSOR_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSD_TYPE_CURSOR_MANAGER, GsdCursorManagerPrivate))
 
 struct GsdCursorManagerPrivate
@@ -58,6 +56,7 @@ struct GsdCursorManagerPrivate
         guint changed_id;
         gboolean cursor_shown;
         GHashTable *monitors;
+        GSettings *osk_settings;
 };
 
 static void     gsd_cursor_manager_class_init  (GsdCursorManagerClass *klass);
@@ -124,14 +123,18 @@ set_cursor_visibility (GsdCursorManager *manager,
                            visible ? "show" : "hide");
         }
 
+        g_settings_set_boolean (manager->priv->osk_settings, "screen-keyboard-enabled", !visible);
+
         manager->priv->cursor_shown = visible;
 }
 
 static void
 monitor_became_active (GnomeIdleMonitor *monitor,
-                       GsdCursorManager *manager)
+                       guint             watch_id,
+                       gpointer          user_data)
 {
         GdkDevice *device;
+        GsdCursorManager *manager = GSD_CURSOR_MANAGER (user_data);
 
         /* Oh, so you're active? */
         g_object_get (G_OBJECT (monitor), "device", &device, NULL);
@@ -170,12 +173,10 @@ device_added_cb (GdkDeviceManager *device_manager,
         g_hash_table_insert (manager->priv->monitors,
                              device,
                              monitor);
-        g_signal_connect (monitor, "became-active",
-                          G_CALLBACK (monitor_became_active), manager);
-        /* We become idle very quickly so that the became-active
-         * kicks in fast */
-        gnome_idle_monitor_add_watch (monitor, IDLE_TIME,
-                                      NULL, NULL, NULL);
+        gnome_idle_monitor_add_user_active_watch (monitor,
+                                                  monitor_became_active,
+                                                  manager,
+                                                  NULL);
 }
 
 static void
@@ -338,6 +339,7 @@ gsd_cursor_manager_init (GsdCursorManager *manager)
                                                          g_direct_equal,
                                                          NULL,
                                                          g_object_unref);
+        manager->priv->osk_settings = g_settings_new ("org.gnome.desktop.a11y.applications");
 }
 
 static void
@@ -351,6 +353,7 @@ gsd_cursor_manager_finalize (GObject *object)
         cursor_manager = GSD_CURSOR_MANAGER (object);
 
         g_clear_pointer (&cursor_manager->priv->monitors, g_hash_table_destroy);
+        g_clear_object (&cursor_manager->priv->osk_settings);
 
         G_OBJECT_CLASS (gsd_cursor_manager_parent_class)->finalize (object);
 }
