@@ -69,6 +69,10 @@
 #define GNOME_KEYRING_DBUS_PATH "/org/gnome/keyring/daemon"
 #define GNOME_KEYRING_DBUS_INTERFACE "org.gnome.keyring.Daemon"
 
+#define GS_DBUS_NAME                            "org.gnome.ScreenSaver"
+#define GS_DBUS_PATH                            "/org/gnome/ScreenSaver"
+#define GS_DBUS_INTERFACE                       "org.gnome.ScreenSaver"
+
 #define CUSTOM_BINDING_SCHEMA SETTINGS_BINDING_DIR ".custom-keybinding"
 
 static const gchar introspection_xml[] =
@@ -929,6 +933,25 @@ do_touchpad_action (GsdMediaKeysManager *manager)
         g_object_unref (settings);
 }
 
+static void
+do_lock_screensaver (GsdMediaKeysManager *manager)
+{
+        GsdMediaKeysManagerPrivate *priv = manager->priv;
+
+        if (priv->connection == NULL) {
+                g_warning ("No existing D-Bus connection trying to handle screensaver lock key");
+                return;
+        }
+        g_dbus_connection_call (manager->priv->connection,
+                                GS_DBUS_NAME,
+                                GS_DBUS_PATH,
+                                GS_DBUS_INTERFACE,
+                                "Lock",
+                                NULL, NULL,
+                                G_DBUS_CALL_FLAGS_NONE, -1,
+                                NULL, NULL, NULL);
+}
+
 static void
 update_dialog (GsdMediaKeysManager *manager,
                GvcMixerStream      *stream,
@@ -1199,7 +1222,6 @@ update_default_source (GsdMediaKeysManager *manager)
 
         if (stream != NULL) {
                 manager->priv->source = g_object_ref (stream);
-                g_message ("update_default_source done ");
         } else {
                 g_warning ("Unable to get default source");
         }
@@ -1947,7 +1969,7 @@ do_action (GsdMediaKeysManager *manager,
                 do_url_action (manager, "mailto", timestamp);
                 break;
         case SCREENSAVER_KEY:
-                execute (manager, "gnome-screensaver-command --lock", FALSE);
+                do_lock_screensaver (manager);
                 break;
         case HELP_KEY:
                 do_url_action (manager, "ghelp", timestamp);
